@@ -163,17 +163,18 @@ class UMCAndSecretAuthenticator(UMCAuthenticator):
 		if user and user.username:
 			return user
 
-		authorization = self.request.headers.get('Authorization')
+		authorization = request.request.headers.get('Authorization')
 		if not authorization:
 			return user
 
 		try:
 			if not authorization.lower().startswith('basic '):
 				raise ValueError()
-			username, password = base64.b64decode(authorization.split(' ', 1)[1].encode('ISO8859-1')).decode('UTF-8').split(':', 1)
+			display_name, password = base64.b64decode(authorization.split(' ', 1)[1].encode('ISO8859-1')).decode('UTF-8').split(':', 1)
 		except (ValueError, IndexError, binascii.Error):
 			raise HTTPError(400)
 
+		username = display_name.lower()
 		get_logger("user").debug("received basic auth request with username=%r", username)
 		try:
 			with open(config.fetch("portal-secret-file")) as fd:
@@ -182,9 +183,9 @@ class UMCAndSecretAuthenticator(UMCAuthenticator):
 			return user
 
 		# compare hashed password to prevent time based side channel attack
-		if hashlib.sha512(password.encode('utf-8')) != hashlib.sha512(config_secret.encode('utf-8')):
-			get_logger("user").warning("password mismatch")
+		if hashlib.sha512(password.encode('utf-8')).hexdigest() != hashlib.sha512(config_secret.encode('utf-8')).hexdigest():
+			get_logger("user").warning("password mismatch: %s != %s", config_secret, password)
 			return user
 
 		groups = self.group_cache.get().get(username, [])
-		return User(username, None, groups, None)
+		return User(username, display_name, groups, headers=dict(request.request.headers))
